==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1alpha1PodPresetSpecFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.kubernetes.client.fluent.Fluent;
import java.util.Collection;

public interface V1alpha1PodPresetSpecFluent<A extends V1alpha1PodPresetSpecFluent<A>> extends Fluent<A>{


    public A addToEnv(int index,V1EnvVar item);
    public A setToEnv(int index,V1EnvVar item);
    public A addToEnv(V1EnvVar... items);
    public A addAllToEnv(Collection<V1EnvVar> items);
    public A removeFromEnv(V1EnvVar... items);
    public A removeAllFromEnv(Collection<V1EnvVar> items);
    
/**
 * This method has been deprecated, please use method buildEnv instead.
 * @return The buildable object.
 */
@Deprecated public List<V1EnvVar> getEnv();
    public List<V1EnvVar> buildEnv();
    public V1EnvVar buildEnv(int index);
    public V1EnvVar buildFirstEnv();
    public V1EnvVar buildLastEnv();
    public V1EnvVar buildMatchingEnv(io.kubernetes.client.fluent.Predicate<V1EnvVarBuilder> predicate);
    public A withEnv(List<V1EnvVar> env);
    public A withEnv(V1EnvVar... env);
    public Boolean hasEnv();
    public V1alpha1PodPresetSpecFluent.EnvNested<A> addNewEnv();
    public V1alpha1PodPresetSpecFluent.EnvNested<A> addNewEnvLike(V1EnvVar item);
    public V1alpha1PodPresetSpecFluent.EnvNested<A> setNewEnvLike(int index,V1EnvVar item);
    public V1alpha1PodPresetSpecFluent.EnvNested<A> editEnv(int index);
    public V1alpha1PodPresetSpecFluent.EnvNested<A> editFirstEnv();
    public V1alpha1PodPresetSpecFluent.EnvNested<A> editLastEnv();
    public V1alpha1PodPresetSpecFluent.EnvNested<A> editMatchingEnv(io.kubernetes.client.fluent.Predicate<V1EnvVarBuilder> predicate);
    public A addToEnvFrom(int index,V1EnvFromSource item);
    public A setToEnvFrom(int index,V1EnvFromSource item);
    public A addToEnvFrom(V1EnvFromSource... items);
    public A addAllToEnvFrom(Collection<V1EnvFromSource> items);
    public A removeFromEnvFrom(V1EnvFromSource... items);
    public A removeAllFromEnvFrom(Collection<V1EnvFromSource> items);
    
/**
 * This method has been deprecated, please use method buildEnvFrom instead.
 * @return The buildable object.
 */
@Deprecated public List<V1EnvFromSource> getEnvFrom();
    public List<V1EnvFromSource> buildEnvFrom();
    public V1EnvFromSource buildEnvFrom(int index);
    public V1EnvFromSource buildFirstEnvFrom();
    public V1EnvFromSource buildLastEnvFrom();
    public V1EnvFromSource buildMatchingEnvFrom(io.kubernetes.client.fluent.Predicate<V1EnvFromSourceBuilder> predicate);
    public A withEnvFrom(List<V1EnvFromSource> envFrom);
    public A withEnvFrom(V1EnvFromSource... envFrom);
    public Boolean hasEnvFrom();
    public V1alpha1PodPresetSpecFluent.EnvFromNested<A> addNewEnvFrom();
    public V1alpha1PodPresetSpecFluent.EnvFromNested<A> addNewEnvFromLike(V1EnvFromSource item);
    public V1alpha1PodPresetSpecFluent.EnvFromNested<A> setNewEnvFromLike(int index,V1EnvFromSource item);
    public V1alpha1PodPresetSpecFluent.EnvFromNested<A> editEnvFrom(int index);
    public V1alpha1PodPresetSpecFluent.EnvFromNested<A> editFirstEnvFrom();
    public V1alpha1PodPresetSpecFluent.EnvFromNested<A> editLastEnvFrom();
    public V1alpha1PodPresetSpecFluent.EnvFromNested<A> editMatchingEnvFrom(io.kubernetes.client.fluent.Predicate<V1EnvFromSourceBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildSelector instead.
 * @return The buildable object.
 */
@Deprecated public V1LabelSelector getSelector();
    public V1LabelSelector buildSelector();
    public A withSelector(V1LabelSelector selector);
    public Boolean hasSelector();
    public V1alpha1PodPresetSpecFluent.SelectorNested<A> withNewSelector();
    public V1alpha1PodPresetSpecFluent.SelectorNested<A> withNewSelectorLike(V1LabelSelector item);
    public V1alpha1PodPresetSpecFluent.SelectorNested<A> editSelector();
    public V1alpha1PodPresetSpecFluent.SelectorNested<A> editOrNewSelector();
    public V1alpha1PodPresetSpecFluent.SelectorNested<A> editOrNewSelectorLike(V1LabelSelector item);
    public A addToVolumeMounts(int index,V1VolumeMount item);
    public A setToVolumeMounts(int index,V1VolumeMount item);
    public A addToVolumeMounts(V1VolumeMount... items);
    public A addAllToVolumeMounts(Collection<V1VolumeMount> items);
    public A removeFromVolumeMounts(V1VolumeMount... items);
    public A removeAllFromVolumeMounts(Collection<V1VolumeMount> items);
    
/**
 * This method has been deprecated, please use method buildVolumeMounts instead.
 * @return The buildable object.
 */
@Deprecated public List<V1VolumeMount> getVolumeMounts();
    public List<V1VolumeMount> buildVolumeMounts();
    public V1VolumeMount buildVolumeMount(int index);
    public V1VolumeMount buildFirstVolumeMount();
    public V1VolumeMount buildLastVolumeMount();
    public V1VolumeMount buildMatchingVolumeMount(io.kubernetes.client.fluent.Predicate<V1VolumeMountBuilder> predicate);
    public A withVolumeMounts(List<V1VolumeMount> volumeMounts);
    public A withVolumeMounts(V1VolumeMount... volumeMounts);
    public Boolean hasVolumeMounts();
    public V1alpha1PodPresetSpecFluent.VolumeMountsNested<A> addNewVolumeMount();
    public V1alpha1PodPresetSpecFluent.VolumeMountsNested<A> addNewVolumeMountLike(V1VolumeMount item);
    public V1alpha1PodPresetSpecFluent.VolumeMountsNested<A> setNewVolumeMountLike(int index,V1VolumeMount item);
    public V1alpha1PodPresetSpecFluent.VolumeMountsNested<A> editVolumeMount(int index);
    public V1alpha1PodPresetSpecFluent.VolumeMountsNested<A> editFirstVolumeMount();
    public V1alpha1PodPresetSpecFluent.VolumeMountsNested<A> editLastVolumeMount();
    public V1alpha1PodPresetSpecFluent.VolumeMountsNested<A> editMatchingVolumeMount(io.kubernetes.client.fluent.Predicate<V1VolumeMountBuilder> predicate);
    public A addToVolumes(int index,V1Volume item);
    public A setToVolumes(int index,V1Volume item);
    public A addToVolumes(V1Volume... items);
    public A addAllToVolumes(Collection<V1Volume> items);
    public A removeFromVolumes(V1Volume... items);
    public A removeAllFromVolumes(Collection<V1Volume> items);
    
/**
 * This method has been deprecated, please use method buildVolumes instead.
 * @return The buildable object.
 */
@Deprecated public List<V1Volume> getVolumes();
    public List<V1Volume> buildVolumes();
    public V1Volume buildVolume(int index);
    public V1Volume buildFirstVolume();
    public V1Volume buildLastVolume();
    public V1Volume buildMatchingVolume(io.kubernetes.client.fluent.Predicate<V1VolumeBuilder> predicate);
    public A withVolumes(List<V1Volume> volumes);
    public A withVolumes(V1Volume... volumes);
    public Boolean hasVolumes();
    public V1alpha1PodPresetSpecFluent.VolumesNested<A> addNewVolume();
    public V1alpha1PodPresetSpecFluent.VolumesNested<A> addNewVolumeLike(V1Volume item);
    public V1alpha1PodPresetSpecFluent.VolumesNested<A> setNewVolumeLike(int index,V1Volume item);
    public V1alpha1PodPresetSpecFluent.VolumesNested<A> editVolume(int index);
    public V1alpha1PodPresetSpecFluent.VolumesNested<A> editFirstVolume();
    public V1alpha1PodPresetSpecFluent.VolumesNested<A> editLastVolume();
    public V1alpha1PodPresetSpecFluent.VolumesNested<A> editMatchingVolume(io.kubernetes.client.fluent.Predicate<V1VolumeBuilder> predicate);

    public interface EnvNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1EnvVarFluent<V1alpha1PodPresetSpecFluent.EnvNested<N>>{

        
    public N and();    public N endEnv();
}
    public interface EnvFromNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1EnvFromSourceFluent<V1alpha1PodPresetSpecFluent.EnvFromNested<N>>{

        
    public N and();    public N endEnvFrom();
}
    public interface SelectorNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1LabelSelectorFluent<V1alpha1PodPresetSpecFluent.SelectorNested<N>>{

        
    public N and();    public N endSelector();
}
    public interface VolumeMountsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1VolumeMountFluent<V1alpha1PodPresetSpecFluent.VolumeMountsNested<N>>{

        
    public N and();    public N endVolumeMount();
}
    public interface VolumesNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1VolumeFluent<V1alpha1PodPresetSpecFluent.VolumesNested<N>>{

        
    public N and();    public N endVolume();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1alpha1PodPresetSpecFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.kubernetes.client.fluent.Fluent;
import java.util.Collection;

public interface V1alpha1PodPresetSpecFluent<A extends V1alpha1PodPresetSpecFluent<A>> extends Fluent<A>{


    public A addToEnv(int index,V1EnvVar item);
    public A setToEnv(int index,V1EnvVar item);
    public A addToEnv(V1EnvVar... items);
    public A addAllToEnv(Collection<V1EnvVar> items);
    public A removeFromEnv(V1EnvVar... items);
    public A removeAllFromEnv(Collection<V1EnvVar> items);
    
/**
 * This method has been deprecated, please use method buildEnv instead.
 * @return The buildable object.
 */
@Deprecated public List<V1EnvVar> getEnv();
    public List<V1EnvVar> buildEnv();
    public V1EnvVar buildEnv(int index);
    public V1EnvVar buildFirstEnv();
    public V1EnvVar buildLastEnv();
    public V1EnvVar buildMatchingEnv(io.kubernetes.client.fluent.Predicate<V1EnvVarBuilder> predicate);
    public Boolean hasMatchingEnv(io.kubernetes.client.fluent.Predicate<V1EnvVarBuilder> predicate);
    public A withEnv(List<V1EnvVar> env);
    public A withEnv(V1EnvVar... env);
    public Boolean hasEnv();
    public V1alpha1PodPresetSpecFluent.EnvNested<A> addNewEnv();
    public V1alpha1PodPresetSpecFluent.EnvNested<A> addNewEnvLike(V1EnvVar item);
    public V1alpha1PodPresetSpecFluent.EnvNested<A> setNewEnvLike(int index,V1EnvVar item);
    public V1alpha1PodPresetSpecFluent.EnvNested<A> editEnv(int index);
    public V1alpha1PodPresetSpecFluent.EnvNested<A> editFirstEnv();
    public V1alpha1PodPresetSpecFluent.EnvNested<A> editLastEnv();
    public V1alpha1PodPresetSpecFluent.EnvNested<A> editMatchingEnv(io.kubernetes.client.fluent.Predicate<V1EnvVarBuilder> predicate);
    public A addToEnvFrom(int index,V1EnvFromSource item);
    public A setToEnvFrom(int index,V1EnvFromSource item);
    public A addToEnvFrom(V1EnvFromSource... items);
    public A addAllToEnvFrom(Collection<V1EnvFromSource> items);
    public A removeFromEnvFrom(V1EnvFromSource... items);
    public A removeAllFromEnvFrom(Collection<V1EnvFromSource> items);
    
/**
 * This method has been deprecated, please use method buildEnvFrom instead.
 * @return The buildable object.
 */
@Deprecated public List<V1EnvFromSource> getEnvFrom();
    public List<V1EnvFromSource> buildEnvFrom();
    public V1EnvFromSource buildEnvFrom(int index);
    public V1EnvFromSource buildFirstEnvFrom();
    public V1EnvFromSource buildLastEnvFrom();
    public V1EnvFromSource buildMatchingEnvFrom(io.kubernetes.client.fluent.Predicate<V1EnvFromSourceBuilder> predicate);
    public Boolean hasMatchingEnvFrom(io.kubernetes.client.fluent.Predicate<V1EnvFromSourceBuilder> predicate);
    public A withEnvFrom(List<V1EnvFromSource> envFrom);
    public A withEnvFrom(V1EnvFromSource... envFrom);
    public Boolean hasEnvFrom();
    public V1alpha1PodPresetSpecFluent.EnvFromNested<A> addNewEnvFrom();
    public V1alpha1PodPresetSpecFluent.EnvFromNested<A> addNewEnvFromLike(V1EnvFromSource item);
    public V1alpha1PodPresetSpecFluent.EnvFromNested<A> setNewEnvFromLike(int index,V1EnvFromSource item);
    public V1alpha1PodPresetSpecFluent.EnvFromNested<A> editEnvFrom(int index);
    public V1alpha1PodPresetSpecFluent.EnvFromNested<A> editFirstEnvFrom();
    public V1alpha1PodPresetSpecFluent.EnvFromNested<A> editLastEnvFrom();
    public V1alpha1PodPresetSpecFluent.EnvFromNested<A> editMatchingEnvFrom(io.kubernetes.client.fluent.Predicate<V1EnvFromSourceBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildSelector instead.
 * @return The buildable object.
 */
@Deprecated public V1LabelSelector getSelector();
    public V1LabelSelector buildSelector();
    public A withSelector(V1LabelSelector selector);
    public Boolean hasSelector();
    public V1alpha1PodPresetSpecFluent.SelectorNested<A> withNewSelector();
    public V1alpha1PodPresetSpecFluent.SelectorNested<A> withNewSelectorLike(V1LabelSelector item);
    public V1alpha1PodPresetSpecFluent.SelectorNested<A> editSelector();
    public V1alpha1PodPresetSpecFluent.SelectorNested<A> editOrNewSelector();
    public V1alpha1PodPresetSpecFluent.SelectorNested<A> editOrNewSelectorLike(V1LabelSelector item);
    public A addToVolumeMounts(int index,V1VolumeMount item);
    public A setToVolumeMounts(int index,V1VolumeMount item);
    public A addToVolumeMounts(V1VolumeMount... items);
    public A addAllToVolumeMounts(Collection<V1VolumeMount> items);
    public A removeFromVolumeMounts(V1VolumeMount... items);
    public A removeAllFromVolumeMounts(Collection<V1VolumeMount> items);
    
/**
 * This method has been deprecated, please use method buildVolumeMounts instead.
 * @return The buildable object.
 */
@Deprecated public List<V1VolumeMount> getVolumeMounts();
    public List<V1VolumeMount> buildVolumeMounts();
    public V1VolumeMount buildVolumeMount(int index);
    public V1VolumeMount buildFirstVolumeMount();
    public V1VolumeMount buildLastVolumeMount();
    public V1VolumeMount buildMatchingVolumeMount(io.kubernetes.client.fluent.Predicate<V1VolumeMountBuilder> predicate);
    public Boolean hasMatchingVolumeMount(io.kubernetes.client.fluent.Predicate<V1VolumeMountBuilder> predicate);
    public A withVolumeMounts(List<V1VolumeMount> volumeMounts);
    public A withVolumeMounts(V1VolumeMount... volumeMounts);
    public Boolean hasVolumeMounts();
    public V1alpha1PodPresetSpecFluent.VolumeMountsNested<A> addNewVolumeMount();
    public V1alpha1PodPresetSpecFluent.VolumeMountsNested<A> addNewVolumeMountLike(V1VolumeMount item);
    public V1alpha1PodPresetSpecFluent.VolumeMountsNested<A> setNewVolumeMountLike(int index,V1VolumeMount item);
    public V1alpha1PodPresetSpecFluent.VolumeMountsNested<A> editVolumeMount(int index);
    public V1alpha1PodPresetSpecFluent.VolumeMountsNested<A> editFirstVolumeMount();
    public V1alpha1PodPresetSpecFluent.VolumeMountsNested<A> editLastVolumeMount();
    public V1alpha1PodPresetSpecFluent.VolumeMountsNested<A> editMatchingVolumeMount(io.kubernetes.client.fluent.Predicate<V1VolumeMountBuilder> predicate);
    public A addToVolumes(int index,V1Volume item);
    public A setToVolumes(int index,V1Volume item);
    public A addToVolumes(V1Volume... items);
    public A addAllToVolumes(Collection<V1Volume> items);
    public A removeFromVolumes(V1Volume... items);
    public A removeAllFromVolumes(Collection<V1Volume> items);
    
/**
 * This method has been deprecated, please use method buildVolumes instead.
 * @return The buildable object.
 */
@Deprecated public List<V1Volume> getVolumes();
    public List<V1Volume> buildVolumes();
    public V1Volume buildVolume(int index);
    public V1Volume buildFirstVolume();
    public V1Volume buildLastVolume();
    public V1Volume buildMatchingVolume(io.kubernetes.client.fluent.Predicate<V1VolumeBuilder> predicate);
    public Boolean hasMatchingVolume(io.kubernetes.client.fluent.Predicate<V1VolumeBuilder> predicate);
    public A withVolumes(List<V1Volume> volumes);
    public A withVolumes(V1Volume... volumes);
    public Boolean hasVolumes();
    public V1alpha1PodPresetSpecFluent.VolumesNested<A> addNewVolume();
    public V1alpha1PodPresetSpecFluent.VolumesNested<A> addNewVolumeLike(V1Volume item);
    public V1alpha1PodPresetSpecFluent.VolumesNested<A> setNewVolumeLike(int index,V1Volume item);
    public V1alpha1PodPresetSpecFluent.VolumesNested<A> editVolume(int index);
    public V1alpha1PodPresetSpecFluent.VolumesNested<A> editFirstVolume();
    public V1alpha1PodPresetSpecFluent.VolumesNested<A> editLastVolume();
    public V1alpha1PodPresetSpecFluent.VolumesNested<A> editMatchingVolume(io.kubernetes.client.fluent.Predicate<V1VolumeBuilder> predicate);

    public interface EnvNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1EnvVarFluent<V1alpha1PodPresetSpecFluent.EnvNested<N>>{

        
    public N and();    public N endEnv();
}
    public interface EnvFromNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1EnvFromSourceFluent<V1alpha1PodPresetSpecFluent.EnvFromNested<N>>{

        
    public N and();    public N endEnvFrom();
}
    public interface SelectorNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1LabelSelectorFluent<V1alpha1PodPresetSpecFluent.SelectorNested<N>>{

        
    public N and();    public N endSelector();
}
    public interface VolumeMountsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1VolumeMountFluent<V1alpha1PodPresetSpecFluent.VolumeMountsNested<N>>{

        
    public N and();    public N endVolumeMount();
}
    public interface VolumesNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1VolumeFluent<V1alpha1PodPresetSpecFluent.VolumesNested<N>>{

        
    public N and();    public N endVolume();
}


}
